==> wasabiD-0.2.983.tgz: package/Base/Form/ComboBox.jsx <==
/**
 * Created by zhiyongwang on 2016-04-26
 * desc:输入框下拉组件，包括日期，日期范围，联级下拉面板,普通下拉组件
 *
 */
require("../../sass/Base/Form/ComboBox.scss");
let React=require("react");
let DateTime=require("./DateTime.jsx");
let DateRange=require("./DateRange.jsx");
let Picker=require("./Picker.jsx");
let Select=require("./Select.jsx");
let DateTimeDrop=React.createClass({
    PropTypes:{
        type:React.PropTypes.oneOf[
                 "date",
                "datetime",
                "daterange",
               "picker",
                "select"
            ],//类型
        name: React.PropTypes.string.isRequired,//对应表单name属性，用于提交
        label:React.PropTypes.string,//描述文字
        placeholder:React.PropTypes.string,//输入框内的提示文字
        valueField: React.PropTypes.string,//数据字段值名称
        textField:React.PropTypes.string,//数据字段文本名称
        value:React.PropTypes.string,//默认value值，
        text:React.PropTypes.string,//默认text值
        className:React.PropTypes.string,//附加新式
        readonly:React.PropTypes.bool,//是否只读,
        hide:React.PropTypes.hide,//是否隐藏 :
        url:React.PropTypes.string,//ajax的后台地址
        backSource:React.PropTypes.string,//ajax的返回的数据源中哪个属性作为数据源,为null时直接后台返回的数据作为数据源
        data:React.PropTypes.string,//数据源
        extraData:React.PropTypes.array,//额外的数据
        onSelect: React.PropTypes.func,//选中后的事件，回传，value,与text
        onClick: React.PropTypes.func,//自定义单击事件
        params:React.PropTypes.object,//下拉选择面板参数
        secondUrl:React.PropTypes.string,//下拉选择面板第二层节点的后台地址,
        secondParams:React.PropTypes.object,//下拉选择面板第二层节点的后台参数
        secondParamsKey:React.PropTypes.string,//下拉选择面板第二层节点的后台参数中传递一级节点value值的参数名称
        thirdUrl:React.PropTypes.string,//下拉选择面板第三层节点的后台地址，
        thirdParams:React.PropTypes.object,//下拉选择面板第二层节点的后台参数
        thiirdParamsKey:React.PropTypes.string,//下拉选择面板第三层节点的后台参数中传递二级节点value值的参数名称
    },
    getDefaultProps:function() {
        return{
                type:"picker",
            label:"",
            placeholder:"",
            value:null,
            readonly:false,
            className:"",
            hide:false,
            url:null,
            secondUrl:null,
            thirdUrl:null,
            params:null,
            secondParams:null,
            secondParamsKey:null,
            thirdParams:null,
            thirdParamsKey:null,
            valueField:"value",
            textField:"text",
            onSelect:null,
        };
    },
    getInitialState:function() {
        return {
            value:this.props.value,
            text:((this.props.type.indexOf("date")>-1)?this.props.value:this.props.text),
            show:false,//是否显示日期选择
        }
    },
    componentWillReceiveProps:function(nextProps) {
        if(this.props.type=="select"&&nextProps.data!=null&&nextProps.data.length>0)
        {
                var newData=[];//重新设定数据格式
            var text=nextProps.text;
                for(let i=0;i<nextProps.data.length;i++)
                {
                    let obj={};
                    obj.text=nextProps.data[i][this.props.textField];
                    obj.value=nextProps.data[i][this.props.valueField];
                    if(obj.value==nextProps.value)
                    {
                        text=obj.text;//t重新根据根据value赋值
                    }
                    newData.push(obj);
                }
                this.setState({
                    data:newData,
                    value: nextProps.value,
                    text: text,
                })

        }
        this.setState({
            value: nextProps.value,
            text:((this.props.type.indexOf("date")>-1)?nextProps.value:nextProps.text),
            data:nextProps.data,
        })
    },
    splitDate:function(splitdate) {//拆分日期格式
        var regs=/^(\d{4})-(\d{2})-(\d{2})$/;
        if(splitdate&&splitdate!=""&&regs.test(splitdate))
        {
            var  returnvalue={
                year:splitdate.split("-")[0],
                month:splitdate.split("-")[1],
                day:splitdate.split("-")[2],
            }
            return returnvalue;
        }
        else {
            null;
        }

    },
    showPicker:function() {//显示日期选择
        if(this.props.readonly)
        {
            //只读不显示
            return ;
        }
        else {
            this.setState({
                show: !this.state.show
            })
        }
    },
    onSelect:function(value,text,name) {//选中事件
        this.setState({
            show:false,
            value:value,
            text:text,
        });
        if( this.props.onSelect!=null)
        {
            this.props.onSelect(value,text,this.props.name);
        }
    },
    changeHandler:function(event) {
        //允许手动输入
        if(this.validateInput) {
            //输入的字符是正确的
            if(event.target.value.length>10)
            {
                return ;//直接返回
            }
            this.setState({
                value: event.target.value
            })
            if (this.props.onSelect != null) {
                this.props.onSelect(event.target.value,event.target.value,this.props.name);
            }
        }
    },
    keyDownHandler:function(event) {
        if((event.keyCode>=48&&event.keyCode<=57)||(event.keyCode>=96&&event.keyCode<=105)||event.keyCode==189||event.keyCode==109||event.keyCode==8||event.keyCode==13||event.keyCode==13||event.keyCode==46||event.keyCode==144)
        {
            //输入的是数值,或者是一个些控制键
            this.validateInput=true;
        }
        else
        {
            this.validateInput=false;
        }
    },
    mouseOutHandler:function(event) {//鼠标移开时隐藏下拉
        var parentE=event.relatedTarget;
        while (parentE&&parentE.parentElement&&parentE.parentElement.nodeName!="BODY")
        {
            if(parentE.className.indexOf("drop")>-1)
            {
                break;
            }
            parentE=parentE.parentElement;
        }

        if((event.relatedTarget==undefined||event.relatedTarget==null)||
            ((parentE.className.indexOf("drop")<0)&&event.relatedTarget.nodeName!="INPUT"))
        {
            this.setState({
                show: false,
            });
        }

    },
    getComponentData:function() {//只读属性，获取对应的字段的数据源
        return this.state.data;
    },
    renderPicker:function(){//下拉面板
        return    <Picker {...this.props} onSelect={this.onSelect}></Picker>
    },
    renderSelect:function(){//普通下拉框
            return <Select {...this.props} onSelect={this.onSelect}></Select>
    },
    renderDate:function() {
        var dateobj=this.splitDate(this.state.value);
        return <DateTime {...dateobj}  onSelect={this.onSelect}></DateTime>

    },
    renderDateRange:function() {
        var firstDate=null;var secondDate=null;
        if(this.state.value!=null&&this.state.value!="") {//传入一到两个值
            var dateArray=this.state.value.split(",");
            if(dateArray.length>0)
            {
                firstDate=(dateArray[0]);
            }
            if(dateArray.length>=2)
            {
                secondDate=(dateArray[1]);
            }
        }
        return <DateRange firstDate={firstDate} secondDate={secondDate} onSelect={this.onSelect}></DateRange>
    },
    render:function() {
        if(this.props.type=="select")
        {
            return (
                this.renderSelect()
            )
        }
        else
        {
            var inputClass="Form-control";
            let props=
            {
                readOnly:this.props.readonly==true?"readonly":null,
                style:this.props.style,
                name:this.props.name,
                placeholder:this.props.placeholder,
                className:"Form-control  "+((!this.props.claasName)?this.props.className:"")
            }

            var control; var controlDropClassName="drop";
            var iconName="dateicon";
            switch (this.props.type)
            {
                case "picker":
                    control=this.renderPicker();
                    controlDropClassName="droppicker";
                    iconName="pickericon";
                    break;
                case "date":
                    control=this.renderDate();
                    controlDropClassName="dropdate";
                    iconName="dateicon";
                    break;
                case "datetime":
                    control=this.renderDate();
                    controlDropClassName="dropdate";
                    iconName="dateicon";
                    break;
                case "daterange":
                    control=this.renderDateRange();
                    controlDropClassName="droprange";
                    iconName="dateicon";
                    break;

            }
            return (
                <div className="combobox" style={{display:this.props.hide==true?"none":"block"}}   onMouseOut={this.mouseOutHandler}>
                    <i className={iconName} onClick={this.showPicker}></i>
                    <input type="text" {...props}  value={this.state.text} onChange={this.changeHandler}  onKeyDown={this.keyDownHandler}    />
                    <div className={controlDropClassName} style={{display:this.state.show==true?"block":"none"}}>
                        {
                            control
                        }

                    </div>
                </div>
            );

        }


    }
});
module.exports=DateTimeDrop;

==> wasabiD-0.3.1.tgz: package/Base/Form/ComboBox.jsx <==
/**
 * Created by zhiyongwang on 2016-04-26
 * desc:输入框下拉组件，包括日期，日期范围，联级下拉面板,普通下拉组件
 *
 */
require("../../sass/Base/Form/ComboBox.scss");
let React=require("react");
let DateTime=require("./DateTime.jsx");
let DateRange=require("./DateRange.jsx");
let Picker=require("./Picker.jsx");
let Select=require("./Select.jsx");
let DateTimeDrop=React.createClass({
    PropTypes:{
        type:React.PropTypes.oneOf[
                 "date",
                "datetime",
                "daterange",
               "picker",
                "select"
            ],//类型
        name: React.PropTypes.string.isRequired,//对应表单name属性，用于提交
        label:React.PropTypes.string,//描述文字
        placeholder:React.PropTypes.string,//输入框内的提示文字
        valueField: React.PropTypes.string,//数据字段值名称
        textField:React.PropTypes.string,//数据字段文本名称
        value:React.PropTypes.string,//默认value值，
        text:React.PropTypes.string,//默认text值
        className:React.PropTypes.string,//附加新式
        readonly:React.PropTypes.bool,//是否只读,
        hide:React.PropTypes.hide,//是否隐藏 :
        url:React.PropTypes.string,//ajax的后台地址
        backSource:React.PropTypes.string,//ajax的返回的数据源中哪个属性作为数据源,为null时直接后台返回的数据作为数据源
        data:React.PropTypes.string,//数据源
        extraData:React.PropTypes.array,//额外的数据
        onSelect: React.PropTypes.func,//选中后的事件，回传，value,与text
        onClick: React.PropTypes.func,//自定义单击事件
        params:React.PropTypes.object,//下拉选择面板参数
        secondUrl:React.PropTypes.string,//下拉选择面板第二层节点的后台地址,
        secondParams:React.PropTypes.object,//下拉选择面板第二层节点的后台参数
        secondParamsKey:React.PropTypes.string,//下拉选择面板第二层节点的后台参数中传递一级节点value值的参数名称
        thirdUrl:React.PropTypes.string,//下拉选择面板第三层节点的后台地址，
        thirdParams:React.PropTypes.object,//下拉选择面板第二层节点的后台参数
        thiirdParamsKey:React.PropTypes.string,//下拉选择面板第三层节点的后台参数中传递二级节点value值的参数名称
    },
    getDefaultProps:function() {
        return{
                type:"picker",
            label:"",
            placeholder:"",
            value:null,
            readonly:false,
            className:"",
            hide:false,
            url:null,
            secondUrl:null,
            thirdUrl:null,
            params:null,
            secondParams:null,
            secondParamsKey:null,
            thirdParams:null,
            thirdParamsKey:null,
            valueField:"value",
            textField:"text",
            onSelect:null,
        };
    },
    getInitialState:function() {
        return {
            value:this.props.value,
            text:((this.props.type.indexOf("date")>-1)?this.props.value:this.props.text),
            show:false,//是否显示日期选择
        }
    },
    componentWillReceiveProps:function(nextProps) {
        if(this.props.type=="select"&&nextProps.data!=null&&nextProps.data.length>0)
        {
                var newData=[];//重新设定数据格式
            var text=nextProps.text;
                for(let i=0;i<nextProps.data.length;i++)
                {
                    let obj={};
                    obj.text=nextProps.data[i][this.props.textField];
                    obj.value=nextProps.data[i][this.props.valueField];
                    if(obj.value==nextProps.value)
                    {
                        text=obj.text;//t重新根据根据value赋值
                    }
                    newData.push(obj);
                }
                this.setState({
                    data:newData,
                    value: nextProps.value,
                    text: text,
                })

        }
        this.setState({
            value: nextProps.value,
            text:((this.props.type.indexOf("date")>-1)?nextProps.value:nextProps.text),
            data:nextProps.data,
        })
    },
    splitDate:function(splitdate) {//拆分日期格式
        var regs=/^(\d{4})-(\d{2})-(\d{2})$/;
        if(splitdate&&splitdate!=""&&regs.test(splitdate))
        {
            var  returnvalue={
                year:splitdate.split("-")[0],
                month:splitdate.split("-")[1],
                day:splitdate.split("-")[2],
            }
            return returnvalue;
        }
        else {
            null;
        }

    },
    showPicker:function() {//显示日期选择
        if(this.props.readonly)
        {
            //只读不显示
            return ;
        }
        else {
            this.setState({
                show: !this.state.show
            })
        }
    },
    onSelect:function(value,text,name) {//选中事件
        this.setState({
            show:false,
            value:value,
            text:text,
        });
        if( this.props.onSelect!=null)
        {
            this.props.onSelect(value,text,this.props.name);
        }
    },
    changeHandler:function(event) {
        //允许手动输入
        if(this.validateInput) {
            //输入的字符是正确的
            if(event.target.value.length>10)
            {
                return ;//直接返回
            }
            this.setState({
                value: event.target.value
            })
            if (this.props.onSelect != null) {
                this.props.onSelect(event.target.value,event.target.value,this.props.name);
            }
        }
    },
    keyDownHandler:function(event) {
        if((event.keyCode>=48&&event.keyCode<=57)||(event.keyCode>=96&&event.keyCode<=105)||event.keyCode==189||event.keyCode==109||event.keyCode==8||event.keyCode==13||event.keyCode==13||event.keyCode==46||event.keyCode==144)
        {
            //输入的是数值,或者是一个些控制键
            this.validateInput=true;
        }
        else
        {
            this.validateInput=false;
        }
    },
    mouseOutHandler:function(event) {//鼠标移开时隐藏下拉
        var parentE=event.relatedTarget;
        while (parentE&&parentE.parentElement&&parentE.parentElement.nodeName!="BODY")
        {
            if(parentE.className.indexOf("drop")>-1)
            {
                break;
            }
            parentE=parentE.parentElement;
        }

        if((event.relatedTarget==undefined||event.relatedTarget==null)||
            ((parentE.className.indexOf("drop")<0)&&event.relatedTarget.nodeName!="INPUT"))
        {
            this.setState({
                show: false,
            });
        }

    },
    getComponentData:function() {//只读属性，获取对应的字段的数据源
        return this.state.data;
    },
    renderPicker:function(){//下拉面板
        return    <Picker {...this.props} onSelect={this.onSelect}></Picker>
    },
    renderSelect:function(){//普通下拉框
            return <Select {...this.props} onSelect={this.onSelect}></Select>
    },
    renderDate:function() {
        var dateobj=this.splitDate(this.state.value);
        return <DateTime {...dateobj}  onSelect={this.onSelect}></DateTime>

    },
    renderDateRange:function() {
        var firstDate=null;var secondDate=null;
        if(this.state.value!=null&&this.state.value!="") {//传入一到两个值
            var dateArray=this.state.value.split(",");
            if(dateArray.length>0)
            {
                firstDate=(dateArray[0]);
            }
            if(dateArray.length>=2)
            {
                secondDate=(dateArray[1]);
            }
        }
        return <DateRange firstDate={firstDate} secondDate={secondDate} onSelect={this.onSelect}></DateRange>
    },
    render:function() {
        if(this.props.type=="select")
        {
            return (
                this.renderSelect()
            )
        }
        else
        {
            var inputClass="form-control";
            let props=
            {
                readOnly:this.props.readonly==true?"readonly":null,
                style:this.props.style,
                name:this.props.name,
                placeholder:this.props.placeholder,
                className:"form-control  "+((!this.props.claasName)?this.props.className:"")
            }

            var control; var controlDropClassName="drop";
            var iconName="dateicon";
            switch (this.props.type)
            {
                case "picker":
                    control=this.renderPicker();
                    controlDropClassName="droppicker";
                    iconName="pickericon";
                    break;
                case "date":
                    control=this.renderDate();
                    controlDropClassName="dropdate";
                    iconName="dateicon";
                    break;
                case "datetime":
                    control=this.renderDate();
                    controlDropClassName="dropdate";
                    iconName="dateicon";
                    break;
                case "daterange":
                    control=this.renderDateRange();
                    controlDropClassName="droprange";
                    iconName="dateicon";
                    break;

            }
            return (
                <div className="combobox" style={{display:this.props.hide==true?"none":"block"}}   onMouseOut={this.mouseOutHandler}>
                    <i className={iconName} onClick={this.showPicker}></i>
                    <input type="text" {...props}  value={this.state.text} onChange={this.changeHandler}  onKeyDown={this.keyDownHandler}    />
                    <div className={controlDropClassName} style={{display:this.state.show==true?"block":"none"}}>
                        {
                            control
                        }

                    </div>
                </div>
            );

        }


    }
});
module.exports=DateTimeDrop;
